REM ###################################################################################################
REM # MSWIN Platform periodically Server Reboot - Startup Oracle cluster components
REM # Author: Amos Geng
REM # Date: 06/17/2015
REM # Description: The batch file is used to startup Oracle cluster components when system restarted
REM # MiCORE_ENV parameters: ORACLE_HOME, GRID_HOME, LOG_LOCATION, SCRIPT_LOCATION 
REM # MiCORE_ENV parameters: USER_INSTANCES, ASM_INSTANCES, PROACTIVE_REBOOT_EMAIL
REM # MICORE_ENV location must be hard coded
REM ###################################################################################################

@echo on

goto main

:funct_set_variable
call C:\micore\scripts\micore_env.bat
set filedatetime=%DATE:~10,4%_%DATE:~4,2%_%DATE:~7,2%_%TIME:~0,2%%TIME:~3,2%%TIME:~6,2%
set filedatetime=%filedatetime: =%
set script_name=micore_server_startup
set script_ver=1.0
set status_log=%LOG_LOCATION%\startup_cluster_%filedatetime%.txt
set all_start_services=%SCRIPT_LOCATION%\micore_reboot\all_start_services.bat
set start_services_command=%SCRIPT_LOCATION%\micore_reboot\start_services_command.bat
set asm_exist=no
set css=install
set cssrunning=notrunning
goto:EOF


:funct_log_header
echo ==================================================== > %status_log%
echo * MSWIN Server Periodically Reboot - Startup      	  >> %status_log%
echo * Date: %filedatetime%                               >> %status_log%
echo * Server: %computername%                             >> %status_log%
echo ==================================================== >> %status_log%
goto:EOF


:funct_asm_exist
for /f "delims=" %%i in ('net start ^| findstr Oracle ^| findstr ASM') do set asm_exist=yes
goto: EOF


:funct_start_services
echo.>>  %status_log%
echo *********Starting Oracle Required Services...********* >>  %status_log%

for /F "delims=" %%i in (%start_services_command%) do (
	net start %%i >> %status_log%
)

echo.>>  %status_log%
for /f "delims=" %%i in ('net start ^| findstr Oracle') do echo [Started]%%i >> %status_log%
echo.>>  %status_log%
goto:EOF


:funct_cssd_status
for /f "delims=" %%i in ('findstr /n "online" %status_log%') do set cssrunning=running

if %cssrunning% == notrunning (
	crsctl start resource ora.cssd >> %status_log%
	crsctl check cssd >> %status_log% 2>&1
	for /f "delims=" %%i in ('findstr /n "online" %status_log%') do set cssrunning=running
	
	if %cssrunning% == notrunning (
			echo to: %PROACTIVE_REBOOT_EMAIL% > %LOG_LOCATION%\startup_%filedatetime%.txt
			echo from: sqlmail@emeralit.com >> %LOG_LOCATION%\startup_%filedatetime%.txt
			echo subject: Critical - %CLIENT_NAME%:%HOST%:Server has been reboot. But, css failed to start. Database was not started yet, please check. >> %LOG_LOCATION%\startup_%filedatetime%.txt
			echo.>> %LOG_LOCATION%\startup_%filedatetime%.txt
			type %status_log% >> %LOG_LOCATION%\startup_%filedatetime%.txt
			echo.>> %LOG_LOCATION%\startup_%filedatetime%.txt
			echo This email was sent by MiCORE monitoring script %script_name% version %script_ver% >> %LOG_LOCATION%\startup_%filedatetime%.txt
			Msmtp -t < %LOG_LOCATION%\startup_%filedatetime%.txt
			exit;
	)
)
goto:EOF


:funct_asm_startup
echo.>>  %status_log%
echo.>>  %status_log%
echo.>>  %status_log%
echo *********Starting up %~1...********* >>  %status_log%
set ORACLE_SID=%~1
set ORACLE_HOME=%GRID_HOME%
sqlplus -s / as sysasm @%SCRIPT_LOCATION%\micore_reboot\micore_startup.sql >> %status_log%
sqlplus -s / as sysasm @%SCRIPT_LOCATION%\micore_reboot\micore_asm_status.sql >> %status_log%
goto:EOF

:funct_db_startup
echo.>>  %status_log%
echo.>>  %status_log%
echo.>>  %status_log%
echo *********Starting up Database %~1...********* >>  %status_log%
set ORACLE_SID=%~1
set ORACLE_HOME=%ORACLE_HOME%
sqlplus -s / as sysdba @%SCRIPT_LOCATION%\micore_reboot\micore_startup.sql >> %status_log%
sqlplus -s / as sysdba @%SCRIPT_LOCATION%\micore_reboot\micore_db_status.sql >> %status_log%
goto:EOF


:funct_crsctl_status
echo. >>  %status_log%
echo. >>  %status_log%
echo. >>  %status_log%
echo *********CRSCTL Status********* >>  %status_log%
echo. >>  %status_log%
crsctl stat res -t >>  %status_log% 2>&1
goto:EOF

::::: Script Entrance from Function Main :::::

:main

call :funct_set_variable
call :funct_log_header
call :funct_asm_exist
call :funct_start_services

::::::::::::::::::::::::::::

echo.>>  %status_log%
echo.>>  %status_log%
echo *********Starting cssd********* >>  %status_log%
echo.>>  %status_log%
crsctl check cssd >> %status_log% 2>&1

for /f "delims=" %%i in ('findstr /n "not recognized" %status_log%') do set css=uninstalled

if %css% == uninstalled ( 
	echo Cluster is not being installed on this server... >>  %status_log%
) else (
	call :funct_cssd_status
)

::::::::::::::::::::::::::::

if %asm_exist%==yes (
	for %%j in (%ASM_INSTANCES%) do (
		call :funct_asm_startup %%j
	)
)

for %%i in (%USER_INSTANCES%) do (
	call :funct_db_startup %%i
)

if %asm_exist%==yes (
	call :funct_crsctl_status
)

echo to: %PROACTIVE_REBOOT_EMAIL% > %LOG_LOCATION%\startup_%filedatetime%.txt
echo from: sqlmail@emeralit.com >> %LOG_LOCATION%\startup_%filedatetime%.txt
echo subject: Proactive - %CLIENT_NAME%:%HOST%:Server has been reboot. Please check database components. >> %LOG_LOCATION%\startup_%filedatetime%.txt
echo.>> %LOG_LOCATION%\startup_%filedatetime%.txt
type %status_log% >> %LOG_LOCATION%\startup_%filedatetime%.txt
echo.>> %LOG_LOCATION%\startup_%filedatetime%.txt
echo This email was sent by MiCORE monitoring script %script_name% version %script_ver% >> %LOG_LOCATION%\startup_%filedatetime%.txt
Msmtp -t < %LOG_LOCATION%\startup_%filedatetime%.txt

goto:EOF